@@ -1,13 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef COLLECTIONEXPIRYJOB_H
-#define COLLECTIONEXPIRYJOB_H
+#pragma once
 
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
 #include <QObject>
 class KJob;
 namespace MailCommon
@@ -17,7 +16,7 @@ class CollectionExpiryJob : public QObject
     Q_OBJECT
 public:
     explicit CollectionExpiryJob(QObject *parent = nullptr);
-    ~CollectionExpiryJob();
+    ~CollectionExpiryJob() override;
 
     void start();
 
@@ -32,4 +31,3 @@ private:
 };
 }
 
-#endif // COLLECTIONEXPIRYJOB_H
