@@ -1,15 +1,14 @@
 /*
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_COLLECTIONGENERALPAGE_H
-#define MAILCOMMON_COLLECTIONGENERALPAGE_H
+#pragma once
 
 #include "mailcommon_export.h"
 
-#include <CollectionPropertiesPage>
+#include <Akonadi/CollectionPropertiesPage>
 
 class QLineEdit;
 
@@ -66,4 +65,3 @@ private:
 AKONADI_COLLECTION_PROPERTIES_PAGE_FACTORY(CollectionGeneralPageFactory, CollectionGeneralPage)
 }
 
-#endif
