@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONADDHEADERTEST_H
-#define FILTERACTIONADDHEADERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class FilterActionAddHeaderTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionAddHeaderTest(QObject *parent = nullptr);
-    ~FilterActionAddHeaderTest();
+    ~FilterActionAddHeaderTest() override;
 private Q_SLOTS:
     void shouldCreateWidget();
     void shouldAddValue();
@@ -30,4 +29,3 @@ private Q_SLOTS:
     void shouldRequiresSieve();
 };
 
-#endif // FILTERACTIONADDHEADERTEST_H
