@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILTERACTIONMISSINGACCOUNTDIALOGTEST_H
-#define FILTERACTIONMISSINGACCOUNTDIALOGTEST_H
+#pragma once
 #include <QObject>
 
 class FilterActionMissingAccountDialogTest : public QObject
@@ -13,9 +12,8 @@ class FilterActionMissingAccountDialogTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionMissingAccountDialogTest(QObject *parent = nullptr);
-    ~FilterActionMissingAccountDialogTest();
+    ~FilterActionMissingAccountDialogTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
 
-#endif // FILTERACTIONMISSINGACCOUNTDIALOGTEST_H
