@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONREMOVEHEADERTEST_H
-#define FILTERACTIONREMOVEHEADERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class FilterActionRemoveHeaderTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionRemoveHeaderTest(QObject *parent = nullptr);
-    ~FilterActionRemoveHeaderTest();
+    ~FilterActionRemoveHeaderTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldHaveSieveRequires();
@@ -26,4 +25,3 @@ private Q_SLOTS:
     void shouldHaveRequiredPart();
 };
 
-#endif // FILTERACTIONREMOVEHEADERTEST_H
