@@ -1,23 +1,21 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filteractionsetstatustest.h"
 #include "../filteractions/filteractionsetstatus.h"
+#include <QComboBox>
 #include <QTest>
 #include <QWidget>
-#include <QComboBox>
 
 FilterActionSetStatusTest::FilterActionSetStatusTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-FilterActionSetStatusTest::~FilterActionSetStatusTest()
-{
-}
+FilterActionSetStatusTest::~FilterActionSetStatusTest() = default;
 
 void FilterActionSetStatusTest::shouldHaveDefaultValue()
 {
