@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERACTIONWITHURLTEST_H
-#define FILTERACTIONWITHURLTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class FilterActionWithUrlTest : public QObject
     Q_OBJECT
 public:
     explicit FilterActionWithUrlTest(QObject *parent = nullptr);
-    ~FilterActionWithUrlTest();
+    ~FilterActionWithUrlTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldClearWidget();
@@ -24,4 +23,3 @@ private Q_SLOTS:
     void shouldTestUrl();
 };
 
-#endif // FILTERACTIONWITHURLTEST_H
