@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERCONVERTTOSIEVERESULTDIALOGTEST_H
-#define FILTERCONVERTTOSIEVERESULTDIALOGTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class FilterConvertToSieveResultDialogTest : public QObject
     Q_OBJECT
 public:
     explicit FilterConvertToSieveResultDialogTest(QObject *parent = nullptr);
-    ~FilterConvertToSieveResultDialogTest();
+    ~FilterConvertToSieveResultDialogTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAddCode();
 };
 
-#endif // FILTERCONVERTTOSIEVERESULTDIALOGTEST_H
