@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FILTERACTIONMISSINGTRANSPORTDIALOG_H
-#define FILTERACTIONMISSINGTRANSPORTDIALOG_H
+#pragma once
 
 #include <QDialog>
 namespace MailTransport
@@ -20,7 +19,7 @@ class FilterActionMissingTransportDialog : public QDialog
     Q_OBJECT
 public:
     explicit FilterActionMissingTransportDialog(const QString &filtername, QWidget *parent = nullptr);
-    ~FilterActionMissingTransportDialog();
+    ~FilterActionMissingTransportDialog() override;
     Q_REQUIRED_RESULT int selectedTransport() const;
 
 private:
@@ -30,4 +29,3 @@ private:
 };
 }
 
-#endif // FILTERACTIONMISSINGTRANSPORTDIALOG_H
