@@ -1,12 +1,11 @@
 /*
 
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef FILTERACTIONUNSETSTATUS_H
-#define FILTERACTIONUNSETSTATUS_H
+#pragma once
 
 #include "filteractionstatus.h"
 namespace MailCommon
@@ -30,4 +29,3 @@ private:
 };
 }
 
-#endif // FILTERACTIONUNSETSTATUS_H
