@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,18 +12,16 @@ using namespace MailCommon;
 InvalidFilterListView::InvalidFilterListView(QWidget *parent)
     : QListView(parent)
 {
-    auto *invalidFilterDelegate = new InvalidFilterListItemDelegate(this, this);
+    auto invalidFilterDelegate = new InvalidFilterListItemDelegate(this, this);
 
-    auto *invalidFilterListModel = new InvalidFilterListModel(this);
+    auto invalidFilterListModel = new InvalidFilterListModel(this);
     connect(invalidFilterDelegate, &InvalidFilterListItemDelegate::showDetails, this, &InvalidFilterListView::showDetails);
-    //connect(this, SIGNAL(pressed(QModelIndex)), SIGNAL(hideInformationWidget()));
+    // connect(this, SIGNAL(pressed(QModelIndex)), SIGNAL(hideInformationWidget()));
     setModel(invalidFilterListModel);
     setItemDelegate(invalidFilterDelegate);
 }
 
-InvalidFilterListView::~InvalidFilterListView()
-{
-}
+InvalidFilterListView::~InvalidFilterListView() = default;
 
 void InvalidFilterListView::setInvalidFilters(const QVector<MailCommon::InvalidFilterInfo> &lst)
 {
