@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,9 +9,9 @@
 #include "kernel/mailkernel.h"
 #include "util/mailutil_p.h"
 
-#include <CollectionStatistics>
-#include <CollectionStatisticsDelegate>
-#include <EntityTreeModel>
+#include <Akonadi/CollectionStatistics>
+#include <Akonadi/CollectionStatisticsDelegate>
+#include <Akonadi/EntityTreeModel>
 
 #include <KConfigGroup>
 #include <KGuiItem>
@@ -36,9 +36,7 @@ FolderTreeView::FolderTreeView(KXMLGUIClient *xmlGuiClient, QWidget *parent, boo
     init(showUnreadCount);
 }
 
-FolderTreeView::~FolderTreeView()
-{
-}
+FolderTreeView::~FolderTreeView() = default;
 
 void FolderTreeView::disableSaveConfig()
 {
@@ -540,7 +538,7 @@ Akonadi::Collection FolderTreeView::currentFolder() const
         const auto collection = current.model()->data(current, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         return collection;
     }
-    return Akonadi::Collection();
+    return {};
 }
 
 void FolderTreeView::mousePressEvent(QMouseEvent *e)
@@ -575,6 +573,13 @@ void FolderTreeView::keyboardSearch(const QString &)
     // either because KMail has one-letter keyboard shortcuts.
 }
 
+void FolderTreeView::setEnableDragDrop(bool enabled)
+{
+#ifndef QT_NO_DRAGANDDROP
+    setDragDropMode(enabled ? QAbstractItemView::DragDrop : QAbstractItemView::NoDragDrop);
+#endif
+}
+
 QModelIndex FolderTreeView::indexBelow(const QModelIndex &current) const
 {
     // if we have children, return first child
@@ -591,7 +596,7 @@ QModelIndex FolderTreeView::indexBelow(const QModelIndex &current) const
     }
 
     if (!parent.isValid()) { // our parent is the tree root and we have no siblings
-        return QModelIndex(); // we reached the bottom of the tree
+        return {}; // we reached the bottom of the tree
     }
 
     // We are the last child, the next index to check is our uncle, parent's first sibling
@@ -616,7 +621,7 @@ QModelIndex FolderTreeView::indexBelow(const QModelIndex &current) const
         grandParent = model()->parent(currentParent);
     }
 
-    return QModelIndex(); // nothing found -> end of tree
+    return {}; // nothing found -> end of tree
 }
 
 QModelIndex FolderTreeView::lastChild(const QModelIndex &current) const
@@ -656,7 +661,7 @@ QModelIndex FolderTreeView::nextUnreadCollection(const QModelIndex &current, Sea
         }
 
         if (!index.isValid()) { // reach end or top of the model
-            return QModelIndex();
+            return {};
         }
 
         // check if the index is a collection
@@ -672,5 +677,5 @@ QModelIndex FolderTreeView::nextUnreadCollection(const QModelIndex &current, Sea
         }
     }
 
-    return QModelIndex(); // no unread collection found
+    return {}; // no unread collection found
 }
