@@ -1,15 +1,14 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef SEARCHRULE_H
-#define SEARCHRULE_H
+#pragma once
 
 #include "mailcommon_export.h"
-#include <AkonadiCore/SearchQuery>
+#include <Akonadi/SearchQuery>
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 class KConfigGroup;
 namespace MailCommon
@@ -238,7 +237,7 @@ public:
     QDataStream &operator>>(QDataStream &) const;
     virtual QString informationAboutNotValidRules() const
     {
-        return QString();
+        return {};
     }
 
 protected:
@@ -263,4 +262,3 @@ private:
 };
 }
 
-#endif // SEARCHRULE_H
