@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef NUMERICDOUBLERULEWIDGETHANDLER_H
-#define NUMERICDOUBLERULEWIDGETHANDLER_H
+#pragma once
 
 #include "interfaces/rulewidgethandler.h"
 
@@ -19,9 +18,7 @@ public:
     {
     }
 
-    ~NumericDoubleRuleWidgetHandler() override
-    {
-    }
+    ~NumericDoubleRuleWidgetHandler() override = default;
 
     QWidget *createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const override;
 
@@ -47,4 +44,3 @@ private:
 };
 }
 
-#endif // NUMERICDOUBLERULEWIDGETHANDLER_H
