@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef SNIPPETATTACHMENTWIDGET_H
-#define SNIPPETATTACHMENTWIDGET_H
+#pragma once
 
 #include "mailcommon_private_export.h"
 #include <QWidget>
@@ -33,4 +32,3 @@ private:
 };
 }
 
-#endif // SNIPPETATTACHMENTWIDGET_H
