@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -11,7 +11,7 @@
 #include <MessageComposer/ComposerLineEdit>
 #include <QTreeView>
 
-#include <Akonadi/Contact/EmailAddressSelectionDialog>
+#include <Akonadi/EmailAddressSelectionDialog>
 
 #include <KLocalizedString>
 #include <QHBoxLayout>
@@ -50,9 +50,7 @@ RedirectWidget::RedirectWidget(QWidget *parent)
     setFocusProxy(mEdit);
 }
 
-RedirectWidget::~RedirectWidget()
-{
-}
+RedirectWidget::~RedirectWidget() = default;
 
 QString RedirectWidget::resend()
 {
